#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id$
# Copyright (C) 2008, Sebastian Ramacher
# This file is released under a modified BSD license. See LICENSE.txt for
# details.
################################################################################

""" Logger

Provides some basic logging functionality based on Python's logging module.
"""

import logging
from btdt.common import random_string

LOGGER_NAME = 'btdt'

LOGLEVELMAPPING = {
    'DEBUG': logging.DEBUG,
    'INFO': logging.INFO,
    'WARNING': logging.WARNING,
    'ERROR': logging.ERROR,
    'CRITICAL': logging.CRITICAL
}

def translate(loglevel):
    """
    Translates loglevel string into it's corresponding integer constant.
    A call with an invalid loglevel string returns the same as called with
    'DEBUG'.
    """

    upper = loglevel.upper()
    if upper not in LOGLEVELMAPPING:
        return LOGLEVELMAPPING['DEBUG']
    else:
        return LOGLEVELMAPPING[upper]

def create_logger(filename=None, filemode='aw', fileloglevel=logging.DEBUG,
                  stdoutloglevel=logging.WARNING):
    """ Actually creates and initializes the logger. """

    logger = logging.getLogger(LOGGER_NAME)
    logger.setLevel(fileloglevel)

    if filename is not None:
        file = logging.FileHandler(filename, filemode)
        # file.setLevel(logging.INFO)

        filefmt = logging.Formatter('%(asctime)s %(levelname)-8s %(module)s: ' \
                                    '%(message)s', '%d %b %Y %H:%M:%S')
        file.setFormatter(filefmt)

        logger.addHandler(file)

    console = logging.StreamHandler()
    console.setLevel(stdoutloglevel)

    consolefmt = logging.Formatter('%(levelname)s: %(message)s')
    console.setFormatter(consolefmt)

    logger.addHandler(console)

    return logger


def init_logger(filename, loglevel, stdoutloglevel):
    """ Initializes the logger. """

    create_logger(filename, fileloglevel=translate(loglevel),
                  stdoutloglevel=translate(stdoutloglevel))

def logger():
    """ Retrives the logger. """

    return logging.getLogger(LOGGER_NAME)
